# SearchSource: Wiley

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

[Wiley](https://onlinelibrary.wiley.com/)
[Wiley text and data mining resources](https://onlinelibrary.wiley.com/library-info/resources/text-and-datamining)

## Add the search source

Download search results and store in `data/search/` directory. API-access not yet available.


## Links
